Scene

Struct Scene 

pub struct Scene { /* private fields */ }

Implementations

Source

impl Scene

pub fn new<S: Into<GodotString>>(path: S) -> Self

Creates a new node from a resource path.

Safety

The scene must point to a “well-behaving, self-contained” component.

  • Must not send references to self or any contained nodes in the subtree to another thread.
  • Must not modify the value of the internal meta _grandeur_src_scene.

TODO: define what this actually means.