pub struct Scene { /* private fields */ }Implementations
Sourceimpl Scene
impl Scene
Sourcepub fn new<S: Into<GodotString>>(path: S) -> Self
pub fn new<S: Into<GodotString>>(path: S) -> Self
Creates a new node from a resource path.
Safety
The scene must point to a “well-behaving, self-contained” component.
- Must not send references to
selfor any contained nodes in the subtree to another thread. - Must not modify the value of the internal meta
_grandeur_src_scene.
TODO: define what this actually means.